#

    	VPN

    		[ ] dedicated IP logistics

    				hotel choose [
    					255.255.255.253,
    					255.255.255.254,
    					255.255.255.255
    				]

    				example:
    					Dubai
    					England
    					Canada

    		[ ] dedicated IP

    				https://www.privateinternetaccess.com/buy-vpn-online#select-plan-desktop

    		[ ] Open VPN compatible

    		[ ] Open VPN docker, { Vultr, Digital Ocean }

    		[ ] route individual requests through a VPN
    			[ ] route a docker container through a VPN?